{% extends 'base.html' %}
{% load i18n %}

{% block title %}
    {% trans "Success" %}
{% endblock %}

{% block content_uncache_tail %}
    <div class="main_container_line">
    <h2>{% trans "Your information has been successfully submitted" %}</h2>
    <h3>{% trans "Thank you for getting in touch with us" %}.</h3>
    </div>
            <!-- IE Clearing -->
            <div id="ie_clearing">&nbsp;</div>
{% endblock %}