import version

__version__ = VERSION = version.VERSION
__doc__ = 'For full documentation review the README file in your package or go to: http://pypi.python.org/pypi/django-dynamic-link/'
__docformat__ = 'txt'